package cn.iocoder.yudao.module.order.api;

import cn.iocoder.boot.module.order.api.OrderApi;
import cn.iocoder.boot.module.order.api.dto.OrderObjectiveApiDO;
import cn.iocoder.boot.module.order.api.dto.OrderRespDTO;
import cn.iocoder.yudao.module.order.dal.dataobject.order.OrderDO;
import cn.iocoder.yudao.module.order.dal.dataobject.orderObjective.OrderObjectiveDO;
import cn.iocoder.yudao.module.order.service.order.OrderObjectiveService;
import cn.iocoder.yudao.module.order.service.order.OrderService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;

@Service
@Validated
public class OrderApiImpl implements OrderApi {
    @Resource
    private OrderService orderService;
    @Resource
    private OrderObjectiveService objectiveService;

    @Override
    public OrderRespDTO getOrder(Long id, String orderNo) {
        OrderDO orderDO;
        if (id != null) {
            orderDO = orderService.getById(id);
        } else {
            orderDO = orderService.selectOne(new LambdaQueryWrapper<OrderDO>().eq(OrderDO::getOrderNo, orderNo).last("limit 1"));
        }
        if (orderDO == null) {
            return null;
        }
        OrderRespDTO orderRespDTO = new OrderRespDTO();
        BeanUtils.copyProperties(orderDO, orderRespDTO);

        OrderObjectiveDO orderObjectiveDO = objectiveService.getByOrderId(id);
        if (orderObjectiveDO == null) {
            return orderRespDTO;
        }
        OrderObjectiveApiDO orderObjectiveApiDO = new OrderObjectiveApiDO();
        BeanUtils.copyProperties(orderObjectiveDO, orderObjectiveApiDO);
        orderRespDTO.setOrderObjectiveDO(orderObjectiveApiDO);
        return orderRespDTO;
    }

    @Override
    public boolean isFirstOrder(Long userId) {
        Long count = orderService.selectCount(new LambdaQueryWrapper<OrderDO>().eq(OrderDO::getUserId, userId));
        return count <= 0;
    }
}
